@@ -1,9 +1,8 @@
-from .manim_loader import *
-from .scene import *
-from .create_project import *
-from .load_project import *
+from .assets import *
 from .commands import *
 from .config import *
+from .create_project import *
 from .edit_project import *
-from .assets import IconNormal, IconSkip, IconLoop, IconCompleteLoop, EditorLogo, EditorBanner
-
+from .load_project import *
+from .manim_loader import *
+from .presentation_classes import *
